@@ -15,49 +15,50 @@
 #' @export
 #' @references \url{http://ocrsdk.com/documentation/apireference/getTaskStatus/}
 #' 
-#' @usage getResults(output="", save_to_file=TRUE)
+#' @usage getResults(output = "", save_to_file = TRUE)
 #' 
 #' @examples \dontrun{
-#' getResults(save_to_file=FALSE)
+#' getResults(save_to_file = FALSE)
 #' }
 
-getResults <- function(output="./", save_to_file=TRUE) {
+getResults <- function(output = "./", save_to_file = TRUE) {
 
-	finished_list <- listFinishedTasks()
-	
-	if (nrow(finished_list) == 0) {
+  finished_list <- listFinishedTasks()
 
-		cat("No Finished Tasks")
+  if (nrow(finished_list) == 0) {
 
-	} else {
+    cat("No Finished Tasks")
 
-		# Set progress bar
-		pb <- progress_bar$new(total = nrow(finished_list))
+  } else {
 
-		if (!save_to_file) {
-			# Add additional col. to finished_list
-			finished_list$results <- NA
-			
-			for (i in seq_along(1:nrow(finished_list))) 
-			{
-				url <- as.character(finished_list$resultUrl[i])
-				temp <- curl_fetch_memory(url)
-				finished_list$results[i] <- rawToChar(temp$content)
-				pb$tick()
-			}
+    # Set progress bar
+    pb <- progress_bar$new(total = nrow(finished_list))
 
-			return(invisible(finished_list))
-		}
+    if (!save_to_file) {
+      # Add additional col. to finished_list
+      finished_list$results <- NA
 
-		finished_list$local_file_path <- NA
+      for (i in seq_along(1:nrow(finished_list))) {
 
-		for (i in seq_along(1:nrow(finished_list))) 
-		{
-			curl_download(as.character(finished_list$resultUrl[i]), destfile=paste0(output, finished_list$id[i]))
-			finished_list$local_file_path[i] <- paste0(output, finished_list$id[i])
-			pb$tick()
-		}
-	}
-	
-	finished_list
+        url <- as.character(finished_list$resultUrl[i])
+        temp <- curl_fetch_memory(url)
+        finished_list$results[i] <- rawToChar(temp$content)
+        pb$tick()
+      }
+
+      return(invisible(finished_list))
+    }
+
+    finished_list$local_file_path <- NA
+
+    for (i in seq_along(1:nrow(finished_list))) {
+
+      curl_download(as.character(finished_list$resultUrl[i]),
+                    destfile = paste0(output, finished_list$id[i]))
+      finished_list$local_file_path[i] <- paste0(output, finished_list$id[i])
+      pb$tick()
+    }
+  }
+
+  finished_list
 }
